ines

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2018 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	InesHeaderSize = 16

	HorizontalMirroring = 0
	VerticalMirroring   = 1
)

Variables

This section is empty.

Functions

func Parse

func Parse(r io.Reader) (rom *models.ROM, err error)

Parse reads from the reader, parses the data and populates a ROM struct accordingly.

The errors it returns may relate to reading errors or ines format errors

Types

This section is empty.

Jump to